tools:::Rd_package_description("plantTracker")
tools:::Rd_package_author("plantTracker")
Maintainer: tools:::Rd_package_maintainer("plantTracker")
The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("plantTracker") tools:::Rd_package_indices("plantTracker")
Use the following code to see the vignette will guide you through using the plantTracker package
vignette(topic = "Suggested_plantTracker_Workflow", package = "plantTracker")
Use the following code to see the vignette goes through the trackSpp() function step-by-step
vignette(topic = "Using_the_plantTracker_trackSpp_function", package = "plantTracker")